# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import event_bus_pb2 as event__bus__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class EventBusStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.JoinEventBus = channel.unary_unary(
                '/dialog.EventBus/JoinEventBus',
                request_serializer=event__bus__pb2.RequestJoinEventBus.SerializeToString,
                response_deserializer=event__bus__pb2.ResponseJoinEventBus.FromString,
                )
        self.KeepAliveEventBus = channel.unary_unary(
                '/dialog.EventBus/KeepAliveEventBus',
                request_serializer=event__bus__pb2.RequestKeepAliveEventBus.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.PostToEventBus = channel.unary_unary(
                '/dialog.EventBus/PostToEventBus',
                request_serializer=event__bus__pb2.RequestPostToEventBus.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class EventBusServicer(object):
    """Missing associated documentation comment in .proto file."""

    def JoinEventBus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeepAliveEventBus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostToEventBus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventBusServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'JoinEventBus': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinEventBus,
                    request_deserializer=event__bus__pb2.RequestJoinEventBus.FromString,
                    response_serializer=event__bus__pb2.ResponseJoinEventBus.SerializeToString,
            ),
            'KeepAliveEventBus': grpc.unary_unary_rpc_method_handler(
                    servicer.KeepAliveEventBus,
                    request_deserializer=event__bus__pb2.RequestKeepAliveEventBus.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'PostToEventBus': grpc.unary_unary_rpc_method_handler(
                    servicer.PostToEventBus,
                    request_deserializer=event__bus__pb2.RequestPostToEventBus.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.EventBus', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventBus(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def JoinEventBus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.EventBus/JoinEventBus',
            event__bus__pb2.RequestJoinEventBus.SerializeToString,
            event__bus__pb2.ResponseJoinEventBus.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeepAliveEventBus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.EventBus/KeepAliveEventBus',
            event__bus__pb2.RequestKeepAliveEventBus.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostToEventBus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.EventBus/PostToEventBus',
            event__bus__pb2.RequestPostToEventBus.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: privacy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='privacy.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rprivacy.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"b\n\x10RequestBlockUser\x12\x30\n\x04peer\x18\x01 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"d\n\x12RequestUnblockUser\x12\x30\n\x04peer\x18\x01 \x01(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"T\n\x17RequestLoadBlockedUsers:9\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"b\n\x18ResponseLoadBlockedUsers\x12\'\n\nuser_peers\x18\x01 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"/\n\x11UpdateUserBlocked\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\"1\n\x13UpdateUserUnblocked\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible2\xdb\x02\n\x07Privacy\x12\x61\n\tBlockUser\x12\x18.dialog.RequestBlockUser\x1a\x13.dialog.ResponseSeq\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Privacy/BlockUser:\x01*\x12g\n\x0bUnblockUser\x12\x1a.dialog.RequestUnblockUser\x1a\x13.dialog.ResponseSeq\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Privacy/UnblockUser:\x01*\x12\x83\x01\n\x10LoadBlockedUsers\x12\x1f.dialog.RequestLoadBlockedUsers\x1a .dialog.ResponseLoadBlockedUsers\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Privacy/LoadBlockedUsers:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_REQUESTBLOCKUSER = _descriptor.Descriptor(
  name='RequestBlockUser',
  full_name='dialog.RequestBlockUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestBlockUser.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=229,
)


_REQUESTUNBLOCKUSER = _descriptor.Descriptor(
  name='RequestUnblockUser',
  full_name='dialog.RequestUnblockUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.RequestUnblockUser.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=331,
)


_REQUESTLOADBLOCKEDUSERS = _descriptor.Descriptor(
  name='RequestLoadBlockedUsers',
  full_name='dialog.RequestLoadBlockedUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=417,
)


_RESPONSELOADBLOCKEDUSERS = _descriptor.Descriptor(
  name='ResponseLoadBlockedUsers',
  full_name='dialog.ResponseLoadBlockedUsers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseLoadBlockedUsers.user_peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=517,
)


_UPDATEUSERBLOCKED = _descriptor.Descriptor(
  name='UpdateUserBlocked',
  full_name='dialog.UpdateUserBlocked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserBlocked.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=566,
)


_UPDATEUSERUNBLOCKED = _descriptor.Descriptor(
  name='UpdateUserUnblocked',
  full_name='dialog.UpdateUserUnblocked',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UpdateUserUnblocked.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=617,
)

_REQUESTBLOCKUSER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTUNBLOCKUSER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_RESPONSELOADBLOCKEDUSERS.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
DESCRIPTOR.message_types_by_name['RequestBlockUser'] = _REQUESTBLOCKUSER
DESCRIPTOR.message_types_by_name['RequestUnblockUser'] = _REQUESTUNBLOCKUSER
DESCRIPTOR.message_types_by_name['RequestLoadBlockedUsers'] = _REQUESTLOADBLOCKEDUSERS
DESCRIPTOR.message_types_by_name['ResponseLoadBlockedUsers'] = _RESPONSELOADBLOCKEDUSERS
DESCRIPTOR.message_types_by_name['UpdateUserBlocked'] = _UPDATEUSERBLOCKED
DESCRIPTOR.message_types_by_name['UpdateUserUnblocked'] = _UPDATEUSERUNBLOCKED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestBlockUser = _reflection.GeneratedProtocolMessageType('RequestBlockUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBLOCKUSER,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestBlockUser)
  })
_sym_db.RegisterMessage(RequestBlockUser)

RequestUnblockUser = _reflection.GeneratedProtocolMessageType('RequestUnblockUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUNBLOCKUSER,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestUnblockUser)
  })
_sym_db.RegisterMessage(RequestUnblockUser)

RequestLoadBlockedUsers = _reflection.GeneratedProtocolMessageType('RequestLoadBlockedUsers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADBLOCKEDUSERS,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadBlockedUsers)
  })
_sym_db.RegisterMessage(RequestLoadBlockedUsers)

ResponseLoadBlockedUsers = _reflection.GeneratedProtocolMessageType('ResponseLoadBlockedUsers', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADBLOCKEDUSERS,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadBlockedUsers)
  })
_sym_db.RegisterMessage(ResponseLoadBlockedUsers)

UpdateUserBlocked = _reflection.GeneratedProtocolMessageType('UpdateUserBlocked', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERBLOCKED,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserBlocked)
  })
_sym_db.RegisterMessage(UpdateUserBlocked)

UpdateUserUnblocked = _reflection.GeneratedProtocolMessageType('UpdateUserUnblocked', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERUNBLOCKED,
  '__module__' : 'privacy_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateUserUnblocked)
  })
_sym_db.RegisterMessage(UpdateUserUnblocked)


DESCRIPTOR._options = None
_REQUESTBLOCKUSER.fields_by_name['peer']._options = None
_REQUESTBLOCKUSER._options = None
_REQUESTUNBLOCKUSER.fields_by_name['peer']._options = None
_REQUESTUNBLOCKUSER._options = None
_REQUESTLOADBLOCKEDUSERS._options = None
_RESPONSELOADBLOCKEDUSERS._options = None
_UPDATEUSERBLOCKED.fields_by_name['uid']._options = None
_UPDATEUSERUNBLOCKED.fields_by_name['uid']._options = None

_PRIVACY = _descriptor.ServiceDescriptor(
  name='Privacy',
  full_name='dialog.Privacy',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=620,
  serialized_end=967,
  methods=[
  _descriptor.MethodDescriptor(
    name='BlockUser',
    full_name='dialog.Privacy.BlockUser',
    index=0,
    containing_service=None,
    input_type=_REQUESTBLOCKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Privacy/BlockUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnblockUser',
    full_name='dialog.Privacy.UnblockUser',
    index=1,
    containing_service=None,
    input_type=_REQUESTUNBLOCKUSER,
    output_type=miscellaneous__pb2._RESPONSESEQ,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/grpc/Privacy/UnblockUser:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadBlockedUsers',
    full_name='dialog.Privacy.LoadBlockedUsers',
    index=2,
    containing_service=None,
    input_type=_REQUESTLOADBLOCKEDUSERS,
    output_type=_RESPONSELOADBLOCKEDUSERS,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Privacy/LoadBlockedUsers:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PRIVACY)

DESCRIPTOR.services_by_name['Privacy'] = _PRIVACY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: threads.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import peers_pb2 as peers__pb2
from . import groups_pb2 as groups__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='threads.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rthreads.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x13miscellaneous.proto\x1a\x15scalapb/scalapb.proto\x1a\x0bpeers.proto\x1a\x0cgroups.proto\"u\n\x0fThreadReference\x12\x34\n\nmessage_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12,\n\x04peer\x18\x02 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible\"\x85\x03\n\x13RequestCreateThread\x12 \n\trandom_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12>\n\x11parent_group_peer\x18\x02 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12:\n\x10start_message_id\x18\x03 \x01(\x0b\x32\x11.dialog.UUIDValueB\r\x8a\xea\x30\t\n\x07visible\x12\r\n\x05title\x18\x04 \x01(\t\x12;\n\x0bjoin_policy\x18\x05 \x01(\x0e\x32&.dialog.RequestCreateThread.JoinPolicy\x12\x33\n\x07members\x18\x06 \x03(\x0b\x32\x13.dialog.UserOutPeerB\r\x8a\xea\x30\t\n\x07visible\"1\n\nJoinPolicy\x12\x0f\n\x0bINVITE_ONLY\x10\x00\x12\x12\n\x0eTHREAD_MEMBERS\x10\x01:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x89\x01\n\x14ResponseCreateThread\x12#\n\x0cthread_group\x18\x01 \x01(\x0b\x32\r.dialog.Group\x12\'\n\nuser_peers\x18\x03 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x02\x10\x03\"\x80\x02\n\x11RequestLiftThread\x12 \n\trandom_id\x18\x01 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\x12>\n\x11parent_group_peer\x18\x02 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x11thread_group_peer\x18\x03 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12+\n\x05title\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"W\n\x12ResponseLiftThread\x12\x1c\n\x05group\x18\x01 \x01(\x0b\x32\r.dialog.Group:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponseJ\x04\x08\x02\x10\x03\"k\n\x17RequestLoadGroupThreads\x12\x32\n\x05group\x18\x01 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07\x63ompact:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"r\n\x18ResponseLoadGroupThreads\x12\x37\n\x07threads\x18\x01 \x03(\x0b\x32\x17.dialog.ThreadReferenceB\r\x8a\xea\x30\t\n\x07visible:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\xb1\x01\n\x11RequestJoinThread\x12>\n\x11parent_group_peer\x18\x02 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible\x12>\n\x11thread_group_peer\x18\x03 \x01(\x0b\x32\x14.dialog.GroupOutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xd8\x03\n\x07Threads\x12s\n\x0c\x43reateThread\x12\x1b.dialog.RequestCreateThread\x1a\x1c.dialog.ResponseCreateThread\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Threads/CreateThread:\x01*\x12k\n\nLiftThread\x12\x19.dialog.RequestLiftThread\x1a\x1a.dialog.ResponseLiftThread\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Threads/LiftThread:\x01*\x12\x83\x01\n\x10LoadGroupThreads\x12\x1f.dialog.RequestLoadGroupThreads\x1a .dialog.ResponseLoadGroupThreads\",\x82\xd3\xe4\x93\x02&\"!/v1/grpc/Threads/LoadGroupThreads:\x01*\x12\x65\n\nJoinThread\x12\x19.dialog.RequestJoinThread\x1a\x14.dialog.ResponseVoid\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/grpc/Threads/JoinThread:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,miscellaneous__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,groups__pb2.DESCRIPTOR,])



_REQUESTCREATETHREAD_JOINPOLICY = _descriptor.EnumDescriptor(
  name='JoinPolicy',
  full_name='dialog.RequestCreateThread.JoinPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVITE_ONLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THREAD_MEMBERS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=607,
  serialized_end=656,
)
_sym_db.RegisterEnumDescriptor(_REQUESTCREATETHREAD_JOINPOLICY)


_THREADREFERENCE = _descriptor.Descriptor(
  name='ThreadReference',
  full_name='dialog.ThreadReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_id', full_name='dialog.ThreadReference.message_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ThreadReference.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=294,
)


_REQUESTCREATETHREAD = _descriptor.Descriptor(
  name='RequestCreateThread',
  full_name='dialog.RequestCreateThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='random_id', full_name='dialog.RequestCreateThread.random_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_group_peer', full_name='dialog.RequestCreateThread.parent_group_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_message_id', full_name='dialog.RequestCreateThread.start_message_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestCreateThread.title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_policy', full_name='dialog.RequestCreateThread.join_policy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='dialog.RequestCreateThread.members', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REQUESTCREATETHREAD_JOINPOLICY,
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=686,
)


_RESPONSECREATETHREAD = _descriptor.Descriptor(
  name='ResponseCreateThread',
  full_name='dialog.ResponseCreateThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='thread_group', full_name='dialog.ResponseCreateThread.thread_group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_peers', full_name='dialog.ResponseCreateThread.user_peers', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=826,
)


_REQUESTLIFTTHREAD = _descriptor.Descriptor(
  name='RequestLiftThread',
  full_name='dialog.RequestLiftThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='random_id', full_name='dialog.RequestLiftThread.random_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_group_peer', full_name='dialog.RequestLiftThread.parent_group_peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread_group_peer', full_name='dialog.RequestLiftThread.thread_group_peer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestLiftThread.title', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=1085,
)


_RESPONSELIFTTHREAD = _descriptor.Descriptor(
  name='ResponseLiftThread',
  full_name='dialog.ResponseLiftThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.ResponseLiftThread.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1174,
)


_REQUESTLOADGROUPTHREADS = _descriptor.Descriptor(
  name='RequestLoadGroupThreads',
  full_name='dialog.RequestLoadGroupThreads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='dialog.RequestLoadGroupThreads.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007compact', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1283,
)


_RESPONSELOADGROUPTHREADS = _descriptor.Descriptor(
  name='ResponseLoadGroupThreads',
  full_name='dialog.ResponseLoadGroupThreads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='threads', full_name='dialog.ResponseLoadGroupThreads.threads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1285,
  serialized_end=1399,
)


_REQUESTJOINTHREAD = _descriptor.Descriptor(
  name='RequestJoinThread',
  full_name='dialog.RequestJoinThread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_group_peer', full_name='dialog.RequestJoinThread.parent_group_peer', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thread_group_peer', full_name='dialog.RequestJoinThread.thread_group_peer', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1579,
)

_THREADREFERENCE.fields_by_name['message_id'].message_type = definitions__pb2._UUIDVALUE
_THREADREFERENCE.fields_by_name['peer'].message_type = peers__pb2._OUTPEER
_REQUESTCREATETHREAD.fields_by_name['parent_group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTCREATETHREAD.fields_by_name['start_message_id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTCREATETHREAD.fields_by_name['join_policy'].enum_type = _REQUESTCREATETHREAD_JOINPOLICY
_REQUESTCREATETHREAD.fields_by_name['members'].message_type = peers__pb2._USEROUTPEER
_REQUESTCREATETHREAD_JOINPOLICY.containing_type = _REQUESTCREATETHREAD
_RESPONSECREATETHREAD.fields_by_name['thread_group'].message_type = groups__pb2._GROUP
_RESPONSECREATETHREAD.fields_by_name['user_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTLIFTTHREAD.fields_by_name['parent_group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLIFTTHREAD.fields_by_name['thread_group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTLIFTTHREAD.fields_by_name['title'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSELIFTTHREAD.fields_by_name['group'].message_type = groups__pb2._GROUP
_REQUESTLOADGROUPTHREADS.fields_by_name['group'].message_type = peers__pb2._GROUPOUTPEER
_RESPONSELOADGROUPTHREADS.fields_by_name['threads'].message_type = _THREADREFERENCE
_REQUESTJOINTHREAD.fields_by_name['parent_group_peer'].message_type = peers__pb2._GROUPOUTPEER
_REQUESTJOINTHREAD.fields_by_name['thread_group_peer'].message_type = peers__pb2._GROUPOUTPEER
DESCRIPTOR.message_types_by_name['ThreadReference'] = _THREADREFERENCE
DESCRIPTOR.message_types_by_name['RequestCreateThread'] = _REQUESTCREATETHREAD
DESCRIPTOR.message_types_by_name['ResponseCreateThread'] = _RESPONSECREATETHREAD
DESCRIPTOR.message_types_by_name['RequestLiftThread'] = _REQUESTLIFTTHREAD
DESCRIPTOR.message_types_by_name['ResponseLiftThread'] = _RESPONSELIFTTHREAD
DESCRIPTOR.message_types_by_name['RequestLoadGroupThreads'] = _REQUESTLOADGROUPTHREADS
DESCRIPTOR.message_types_by_name['ResponseLoadGroupThreads'] = _RESPONSELOADGROUPTHREADS
DESCRIPTOR.message_types_by_name['RequestJoinThread'] = _REQUESTJOINTHREAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ThreadReference = _reflection.GeneratedProtocolMessageType('ThreadReference', (_message.Message,), {
  'DESCRIPTOR' : _THREADREFERENCE,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ThreadReference)
  })
_sym_db.RegisterMessage(ThreadReference)

RequestCreateThread = _reflection.GeneratedProtocolMessageType('RequestCreateThread', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCREATETHREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCreateThread)
  })
_sym_db.RegisterMessage(RequestCreateThread)

ResponseCreateThread = _reflection.GeneratedProtocolMessageType('ResponseCreateThread', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSECREATETHREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseCreateThread)
  })
_sym_db.RegisterMessage(ResponseCreateThread)

RequestLiftThread = _reflection.GeneratedProtocolMessageType('RequestLiftThread', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLIFTTHREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLiftThread)
  })
_sym_db.RegisterMessage(RequestLiftThread)

ResponseLiftThread = _reflection.GeneratedProtocolMessageType('ResponseLiftThread', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELIFTTHREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLiftThread)
  })
_sym_db.RegisterMessage(ResponseLiftThread)

RequestLoadGroupThreads = _reflection.GeneratedProtocolMessageType('RequestLoadGroupThreads', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADGROUPTHREADS,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadGroupThreads)
  })
_sym_db.RegisterMessage(RequestLoadGroupThreads)

ResponseLoadGroupThreads = _reflection.GeneratedProtocolMessageType('ResponseLoadGroupThreads', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADGROUPTHREADS,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadGroupThreads)
  })
_sym_db.RegisterMessage(ResponseLoadGroupThreads)

RequestJoinThread = _reflection.GeneratedProtocolMessageType('RequestJoinThread', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTJOINTHREAD,
  '__module__' : 'threads_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestJoinThread)
  })
_sym_db.RegisterMessage(RequestJoinThread)


DESCRIPTOR._options = None
_THREADREFERENCE.fields_by_name['message_id']._options = None
_THREADREFERENCE.fields_by_name['peer']._options = None
_REQUESTCREATETHREAD.fields_by_name['random_id']._options = None
_REQUESTCREATETHREAD.fields_by_name['parent_group_peer']._options = None
_REQUESTCREATETHREAD.fields_by_name['start_message_id']._options = None
_REQUESTCREATETHREAD.fields_by_name['members']._options = None
_REQUESTCREATETHREAD._options = None
_RESPONSECREATETHREAD._options = None
_REQUESTLIFTTHREAD.fields_by_name['random_id']._options = None
_REQUESTLIFTTHREAD.fields_by_name['parent_group_peer']._options = None
_REQUESTLIFTTHREAD.fields_by_name['thread_group_peer']._options = None
_REQUESTLIFTTHREAD._options = None
_RESPONSELIFTTHREAD._options = None
_REQUESTLOADGROUPTHREADS.fields_by_name['group']._options = None
_REQUESTLOADGROUPTHREADS._options = None
_RESPONSELOADGROUPTHREADS.fields_by_name['threads']._options = None
_RESPONSELOADGROUPTHREADS._options = None
_REQUESTJOINTHREAD.fields_by_name['parent_group_peer']._options = None
_REQUESTJOINTHREAD.fields_by_name['thread_group_peer']._options = None
_REQUESTJOINTHREAD._options = None

_THREADS = _descriptor.ServiceDescriptor(
  name='Threads',
  full_name='dialog.Threads',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1582,
  serialized_end=2054,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateThread',
    full_name='dialog.Threads.CreateThread',
    index=0,
    containing_service=None,
    input_type=_REQUESTCREATETHREAD,
    output_type=_RESPONSECREATETHREAD,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Threads/CreateThread:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LiftThread',
    full_name='dialog.Threads.LiftThread',
    index=1,
    containing_service=None,
    input_type=_REQUESTLIFTTHREAD,
    output_type=_RESPONSELIFTTHREAD,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Threads/LiftThread:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadGroupThreads',
    full_name='dialog.Threads.LoadGroupThreads',
    index=2,
    containing_service=None,
    input_type=_REQUESTLOADGROUPTHREADS,
    output_type=_RESPONSELOADGROUPTHREADS,
    serialized_options=b'\202\323\344\223\002&\"!/v1/grpc/Threads/LoadGroupThreads:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JoinThread',
    full_name='dialog.Threads.JoinThread',
    index=3,
    containing_service=None,
    input_type=_REQUESTJOINTHREAD,
    output_type=miscellaneous__pb2._RESPONSEVOID,
    serialized_options=b'\202\323\344\223\002 \"\033/v1/grpc/Threads/JoinThread:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_THREADS)

DESCRIPTOR.services_by_name['Threads'] = _THREADS

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='peers.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bpeers.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\"\x8d\x01\n\x04Peer\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x10.dialog.PeerTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x19\n\x02id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12;\n\x06str_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"\xb3\x01\n\x07OutPeer\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x10.dialog.PeerTypeB\r\x8a\xea\x30\t\n\x07visible\x12\x19\n\x02id\x18\x02 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x03 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12;\n\x06str_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\r\x8a\xea\x30\t\n\x07visible\"L\n\x0bUserOutPeer\x12\x1a\n\x03uid\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\"R\n\x0cGroupOutPeer\x12\x1f\n\x08group_id\x18\x01 \x01(\x05\x42\r\x8a\xea\x30\t\n\x07visible\x12!\n\x0b\x61\x63\x63\x65ss_hash\x18\x02 \x01(\x03\x42\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger*{\n\x08PeerType\x12\x14\n\x10PEERTYPE_UNKNOWN\x10\x00\x12\x14\n\x10PEERTYPE_PRIVATE\x10\x01\x12\x12\n\x0ePEERTYPE_GROUP\x10\x02\x12\x1d\n\x19PEERTYPE_ENCRYPTEDPRIVATE\x10\x03\x12\x10\n\x0cPEERTYPE_SIP\x10\x04\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_PEERTYPE = _descriptor.EnumDescriptor(
  name='PeerType',
  full_name='dialog.PeerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PEERTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEERTYPE_PRIVATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEERTYPE_GROUP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEERTYPE_ENCRYPTEDPRIVATE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEERTYPE_SIP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=585,
  serialized_end=708,
)
_sym_db.RegisterEnumDescriptor(_PEERTYPE)

PeerType = enum_type_wrapper.EnumTypeWrapper(_PEERTYPE)
PEERTYPE_UNKNOWN = 0
PEERTYPE_PRIVATE = 1
PEERTYPE_GROUP = 2
PEERTYPE_ENCRYPTEDPRIVATE = 3
PEERTYPE_SIP = 4



_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='dialog.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.Peer.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Peer.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_id', full_name='dialog.Peer.str_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=239,
)


_OUTPEER = _descriptor.Descriptor(
  name='OutPeer',
  full_name='dialog.OutPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.OutPeer.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.OutPeer.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.OutPeer.access_hash', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_id', full_name='dialog.OutPeer.str_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=421,
)


_USEROUTPEER = _descriptor.Descriptor(
  name='UserOutPeer',
  full_name='dialog.UserOutPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='dialog.UserOutPeer.uid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.UserOutPeer.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=499,
)


_GROUPOUTPEER = _descriptor.Descriptor(
  name='GroupOutPeer',
  full_name='dialog.GroupOutPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='dialog.GroupOutPeer.group_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.GroupOutPeer.access_hash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=583,
)

_PEER.fields_by_name['type'].enum_type = _PEERTYPE
_PEER.fields_by_name['str_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OUTPEER.fields_by_name['type'].enum_type = _PEERTYPE
_OUTPEER.fields_by_name['str_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['OutPeer'] = _OUTPEER
DESCRIPTOR.message_types_by_name['UserOutPeer'] = _USEROUTPEER
DESCRIPTOR.message_types_by_name['GroupOutPeer'] = _GROUPOUTPEER
DESCRIPTOR.enum_types_by_name['PeerType'] = _PEERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
  'DESCRIPTOR' : _PEER,
  '__module__' : 'peers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Peer)
  })
_sym_db.RegisterMessage(Peer)

OutPeer = _reflection.GeneratedProtocolMessageType('OutPeer', (_message.Message,), {
  'DESCRIPTOR' : _OUTPEER,
  '__module__' : 'peers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.OutPeer)
  })
_sym_db.RegisterMessage(OutPeer)

UserOutPeer = _reflection.GeneratedProtocolMessageType('UserOutPeer', (_message.Message,), {
  'DESCRIPTOR' : _USEROUTPEER,
  '__module__' : 'peers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UserOutPeer)
  })
_sym_db.RegisterMessage(UserOutPeer)

GroupOutPeer = _reflection.GeneratedProtocolMessageType('GroupOutPeer', (_message.Message,), {
  'DESCRIPTOR' : _GROUPOUTPEER,
  '__module__' : 'peers_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupOutPeer)
  })
_sym_db.RegisterMessage(GroupOutPeer)


DESCRIPTOR._options = None
_PEER.fields_by_name['type']._options = None
_PEER.fields_by_name['id']._options = None
_PEER.fields_by_name['str_id']._options = None
_OUTPEER.fields_by_name['type']._options = None
_OUTPEER.fields_by_name['id']._options = None
_OUTPEER.fields_by_name['access_hash']._options = None
_OUTPEER.fields_by_name['str_id']._options = None
_USEROUTPEER.fields_by_name['uid']._options = None
_USEROUTPEER.fields_by_name['access_hash']._options = None
_GROUPOUTPEER.fields_by_name['group_id']._options = None
_GROUPOUTPEER.fields_by_name['access_hash']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import config_sync_pb2 as config__sync__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class ConfigSyncStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetParameters = channel.unary_unary(
                '/dialog.ConfigSync/GetParameters',
                request_serializer=config__sync__pb2.RequestGetParameters.SerializeToString,
                response_deserializer=config__sync__pb2.ResponseGetParameters.FromString,
                )
        self.EditParameter = channel.unary_unary(
                '/dialog.ConfigSync/EditParameter',
                request_serializer=config__sync__pb2.RequestEditParameter.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.FeatureFlags = channel.unary_unary(
                '/dialog.ConfigSync/FeatureFlags',
                request_serializer=config__sync__pb2.RequestFeatureFlags.SerializeToString,
                response_deserializer=config__sync__pb2.ResponseFeatureFlags.FromString,
                )


class ConfigSyncServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditParameter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeatureFlags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigSyncServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetParameters,
                    request_deserializer=config__sync__pb2.RequestGetParameters.FromString,
                    response_serializer=config__sync__pb2.ResponseGetParameters.SerializeToString,
            ),
            'EditParameter': grpc.unary_unary_rpc_method_handler(
                    servicer.EditParameter,
                    request_deserializer=config__sync__pb2.RequestEditParameter.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'FeatureFlags': grpc.unary_unary_rpc_method_handler(
                    servicer.FeatureFlags,
                    request_deserializer=config__sync__pb2.RequestFeatureFlags.FromString,
                    response_serializer=config__sync__pb2.ResponseFeatureFlags.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.ConfigSync', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConfigSync(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/GetParameters',
            config__sync__pb2.RequestGetParameters.SerializeToString,
            config__sync__pb2.ResponseGetParameters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditParameter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/EditParameter',
            config__sync__pb2.RequestEditParameter.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeatureFlags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.ConfigSync/FeatureFlags',
            config__sync__pb2.RequestFeatureFlags.SerializeToString,
            config__sync__pb2.ResponseFeatureFlags.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: miniappsregistry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import definitions_pb2 as definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='miniappsregistry.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16miniappsregistry.proto\x12\x06\x64ialog\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x64\x65\x66initions.proto\"\xc7\x02\n\x07MiniApp\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12!\n\x08\x61pp_type\x18\x02 \x01(\x0e\x32\x0f.dialog.AppType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x0c\n\x04icon\x18\x06 \x01(\t\x12\x0c\n\x04link\x18\x07 \x01(\t\x12\x16\n\x0emodified_at_ts\x18\n \x01(\x03\x12\x12\n\nis_enabled\x18\x0b \x01(\x08\x12-\n\x07locales\x18\x0c \x03(\x0b\x32\x1c.dialog.MiniApp.LocalesEntry\x12\x13\n\x0bpermissions\x18\r \x03(\t\x1a.\n\x0cLocalesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\x95\x02\n\rUpdateMiniApp\x12\x39\n\rapp_lifecycle\x18\x01 \x01(\x0e\x32\".dialog.UpdateMiniApp.AppLifecycle\x12!\n\x08\x61pp_data\x18\x02 \x01(\x0b\x32\x0f.dialog.MiniApp\x12\x12\n\nprev_clock\x18\x03 \x01(\x03\"\x91\x01\n\x0c\x41ppLifecycle\x12\x18\n\x14\x41PPLIFECYCLE_CREATED\x10\x00\x12\x18\n\x14\x41PPLIFECYCLE_UPDATED\x10\x01\x12\x18\n\x14\x41PPLIFECYCLE_ENABLED\x10\x02\x12\x19\n\x15\x41PPLIFECYCLE_DISABLED\x10\x03\x12\x18\n\x14\x41PPLIFECYCLE_DELETED\x10\x04\"$\n\x0eGetAppsRequest\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03\"?\n\x0fGetAppsResponse\x12\x1d\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x0f.dialog.MiniApp\x12\r\n\x05\x63lock\x18\x02 \x01(\x03\" \n\x0e\x46indAppRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"/\n\x0f\x46indAppResponse\x12\x1c\n\x03\x61pp\x18\x01 \x01(\x0b\x32\x0f.dialog.MiniApp\"<\n\x17IssueAccessTokenRequest\x12!\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\"+\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"|\n\x15GetExtensionsResponse\x12\x32\n\x12message_extensions\x18\x01 \x03(\x0b\x32\x16.dialog.ExtensionPoint\x12/\n\x0f\x63hat_extensions\x18\x02 \x03(\x0b\x32\x16.dialog.ExtensionPoint\"\xce\x01\n\x0e\x45xtensionPoint\x12!\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x37\n\x12message_conditions\x18\x04 \x01(\x0b\x32\x19.dialog.MessageConditionsH\x00\x12\x33\n\x10group_conditions\x18\x05 \x01(\x0b\x32\x17.dialog.GroupConditionsH\x00\x42\x0c\n\nconditions\"\xbb\x02\n\x11MessageConditions\x12\x45\n\x11message_condition\x18\x01 \x03(\x0b\x32*.dialog.MessageConditions.MessageCondition\x1a\xde\x01\n\x10MessageCondition\x12\x14\n\x0ctext_message\x18\x01 \x01(\t\x12V\n\x10\x64ocument_message\x18\x02 \x01(\x0b\x32<.dialog.MessageConditions.MessageCondition.DocumentCondition\x1a\\\n\x11\x44ocumentCondition\x12\x10\n\x08is_image\x18\x01 \x01(\x08\x12\x10\n\x08is_video\x18\x02 \x01(\x08\x12\x10\n\x08is_audio\x18\x03 \x01(\x08\x12\x11\n\tmime_type\x18\x04 \x03(\t\"\xa0\x01\n\x0fGroupConditions\x12?\n\x0fgroup_condition\x18\x01 \x03(\x0b\x32&.dialog.GroupConditions.GroupCondition\x1aL\n\x0eGroupCondition\x12\x12\n\ngroup_type\x18\x01 \x01(\t\x12\x12\n\nvisibility\x18\x02 \x01(\t\x12\x12\n\npermission\x18\x03 \x03(\t*$\n\x07\x41ppType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08WEB_VIEW\x10\x01\x32\xab\x02\n\x17\x43lientsMiniAppsRegistry\x12:\n\x07\x46indApp\x12\x16.dialog.FindAppRequest\x1a\x17.dialog.FindAppResponse\x12:\n\x07GetApps\x12\x16.dialog.GetAppsRequest\x1a\x17.dialog.GetAppsResponse\x12\x46\n\rGetExtensions\x12\x16.google.protobuf.Empty\x1a\x1d.dialog.GetExtensionsResponse\x12P\n\x10IssueAccessToken\x12\x1f.dialog.IssueAccessTokenRequest\x1a\x1b.dialog.AccessTokenResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,])

_APPTYPE = _descriptor.EnumDescriptor(
  name='AppType',
  full_name='dialog.AppType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEB_VIEW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1833,
  serialized_end=1869,
)
_sym_db.RegisterEnumDescriptor(_APPTYPE)

AppType = enum_type_wrapper.EnumTypeWrapper(_APPTYPE)
UNKNOWN = 0
WEB_VIEW = 1


_UPDATEMINIAPP_APPLIFECYCLE = _descriptor.EnumDescriptor(
  name='AppLifecycle',
  full_name='dialog.UpdateMiniApp.AppLifecycle',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_CREATED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_UPDATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_ENABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_DISABLED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPLIFECYCLE_DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=577,
  serialized_end=722,
)
_sym_db.RegisterEnumDescriptor(_UPDATEMINIAPP_APPLIFECYCLE)


_MINIAPP_LOCALESENTRY = _descriptor.Descriptor(
  name='LocalesEntry',
  full_name='dialog.MiniApp.LocalesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dialog.MiniApp.LocalesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='dialog.MiniApp.LocalesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=430,
)

_MINIAPP = _descriptor.Descriptor(
  name='MiniApp',
  full_name='dialog.MiniApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.MiniApp.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_type', full_name='dialog.MiniApp.app_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='dialog.MiniApp.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='dialog.MiniApp.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='dialog.MiniApp.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='dialog.MiniApp.icon', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='dialog.MiniApp.link', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at_ts', full_name='dialog.MiniApp.modified_at_ts', index=7,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='dialog.MiniApp.is_enabled', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locales', full_name='dialog.MiniApp.locales', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.MiniApp.permissions', index=10,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MINIAPP_LOCALESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=442,
)


_UPDATEMINIAPP = _descriptor.Descriptor(
  name='UpdateMiniApp',
  full_name='dialog.UpdateMiniApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_lifecycle', full_name='dialog.UpdateMiniApp.app_lifecycle', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_data', full_name='dialog.UpdateMiniApp.app_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_clock', full_name='dialog.UpdateMiniApp.prev_clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEMINIAPP_APPLIFECYCLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=722,
)


_GETAPPSREQUEST = _descriptor.Descriptor(
  name='GetAppsRequest',
  full_name='dialog.GetAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.GetAppsRequest.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=760,
)


_GETAPPSRESPONSE = _descriptor.Descriptor(
  name='GetAppsResponse',
  full_name='dialog.GetAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='dialog.GetAppsResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.GetAppsResponse.clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=825,
)


_FINDAPPREQUEST = _descriptor.Descriptor(
  name='FindAppRequest',
  full_name='dialog.FindAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.FindAppRequest.app_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=859,
)


_FINDAPPRESPONSE = _descriptor.Descriptor(
  name='FindAppResponse',
  full_name='dialog.FindAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app', full_name='dialog.FindAppResponse.app', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=908,
)


_ISSUEACCESSTOKENREQUEST = _descriptor.Descriptor(
  name='IssueAccessTokenRequest',
  full_name='dialog.IssueAccessTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.IssueAccessTokenRequest.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=910,
  serialized_end=970,
)


_ACCESSTOKENRESPONSE = _descriptor.Descriptor(
  name='AccessTokenResponse',
  full_name='dialog.AccessTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='dialog.AccessTokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1015,
)


_GETEXTENSIONSRESPONSE = _descriptor.Descriptor(
  name='GetExtensionsResponse',
  full_name='dialog.GetExtensionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_extensions', full_name='dialog.GetExtensionsResponse.message_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_extensions', full_name='dialog.GetExtensionsResponse.chat_extensions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1141,
)


_EXTENSIONPOINT = _descriptor.Descriptor(
  name='ExtensionPoint',
  full_name='dialog.ExtensionPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.ExtensionPoint.app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='dialog.ExtensionPoint.action', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='dialog.ExtensionPoint.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_conditions', full_name='dialog.ExtensionPoint.message_conditions', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_conditions', full_name='dialog.ExtensionPoint.group_conditions', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='conditions', full_name='dialog.ExtensionPoint.conditions',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1144,
  serialized_end=1350,
)


_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION = _descriptor.Descriptor(
  name='DocumentCondition',
  full_name='dialog.MessageConditions.MessageCondition.DocumentCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_image', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_image', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_video', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_video', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_audio', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.is_audio', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='dialog.MessageConditions.MessageCondition.DocumentCondition.mime_type', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1576,
  serialized_end=1668,
)

_MESSAGECONDITIONS_MESSAGECONDITION = _descriptor.Descriptor(
  name='MessageCondition',
  full_name='dialog.MessageConditions.MessageCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text_message', full_name='dialog.MessageConditions.MessageCondition.text_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_message', full_name='dialog.MessageConditions.MessageCondition.document_message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1668,
)

_MESSAGECONDITIONS = _descriptor.Descriptor(
  name='MessageConditions',
  full_name='dialog.MessageConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_condition', full_name='dialog.MessageConditions.message_condition', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGECONDITIONS_MESSAGECONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1353,
  serialized_end=1668,
)


_GROUPCONDITIONS_GROUPCONDITION = _descriptor.Descriptor(
  name='GroupCondition',
  full_name='dialog.GroupConditions.GroupCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_type', full_name='dialog.GroupConditions.GroupCondition.group_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='dialog.GroupConditions.GroupCondition.visibility', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='permission', full_name='dialog.GroupConditions.GroupCondition.permission', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1755,
  serialized_end=1831,
)

_GROUPCONDITIONS = _descriptor.Descriptor(
  name='GroupConditions',
  full_name='dialog.GroupConditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_condition', full_name='dialog.GroupConditions.group_condition', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GROUPCONDITIONS_GROUPCONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1831,
)

_MINIAPP_LOCALESENTRY.containing_type = _MINIAPP
_MINIAPP.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_MINIAPP.fields_by_name['app_type'].enum_type = _APPTYPE
_MINIAPP.fields_by_name['locales'].message_type = _MINIAPP_LOCALESENTRY
_UPDATEMINIAPP.fields_by_name['app_lifecycle'].enum_type = _UPDATEMINIAPP_APPLIFECYCLE
_UPDATEMINIAPP.fields_by_name['app_data'].message_type = _MINIAPP
_UPDATEMINIAPP_APPLIFECYCLE.containing_type = _UPDATEMINIAPP
_GETAPPSRESPONSE.fields_by_name['apps'].message_type = _MINIAPP
_FINDAPPRESPONSE.fields_by_name['app'].message_type = _MINIAPP
_ISSUEACCESSTOKENREQUEST.fields_by_name['app_id'].message_type = definitions__pb2._UUIDVALUE
_GETEXTENSIONSRESPONSE.fields_by_name['message_extensions'].message_type = _EXTENSIONPOINT
_GETEXTENSIONSRESPONSE.fields_by_name['chat_extensions'].message_type = _EXTENSIONPOINT
_EXTENSIONPOINT.fields_by_name['app_id'].message_type = definitions__pb2._UUIDVALUE
_EXTENSIONPOINT.fields_by_name['message_conditions'].message_type = _MESSAGECONDITIONS
_EXTENSIONPOINT.fields_by_name['group_conditions'].message_type = _GROUPCONDITIONS
_EXTENSIONPOINT.oneofs_by_name['conditions'].fields.append(
  _EXTENSIONPOINT.fields_by_name['message_conditions'])
_EXTENSIONPOINT.fields_by_name['message_conditions'].containing_oneof = _EXTENSIONPOINT.oneofs_by_name['conditions']
_EXTENSIONPOINT.oneofs_by_name['conditions'].fields.append(
  _EXTENSIONPOINT.fields_by_name['group_conditions'])
_EXTENSIONPOINT.fields_by_name['group_conditions'].containing_oneof = _EXTENSIONPOINT.oneofs_by_name['conditions']
_MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION.containing_type = _MESSAGECONDITIONS_MESSAGECONDITION
_MESSAGECONDITIONS_MESSAGECONDITION.fields_by_name['document_message'].message_type = _MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION
_MESSAGECONDITIONS_MESSAGECONDITION.containing_type = _MESSAGECONDITIONS
_MESSAGECONDITIONS.fields_by_name['message_condition'].message_type = _MESSAGECONDITIONS_MESSAGECONDITION
_GROUPCONDITIONS_GROUPCONDITION.containing_type = _GROUPCONDITIONS
_GROUPCONDITIONS.fields_by_name['group_condition'].message_type = _GROUPCONDITIONS_GROUPCONDITION
DESCRIPTOR.message_types_by_name['MiniApp'] = _MINIAPP
DESCRIPTOR.message_types_by_name['UpdateMiniApp'] = _UPDATEMINIAPP
DESCRIPTOR.message_types_by_name['GetAppsRequest'] = _GETAPPSREQUEST
DESCRIPTOR.message_types_by_name['GetAppsResponse'] = _GETAPPSRESPONSE
DESCRIPTOR.message_types_by_name['FindAppRequest'] = _FINDAPPREQUEST
DESCRIPTOR.message_types_by_name['FindAppResponse'] = _FINDAPPRESPONSE
DESCRIPTOR.message_types_by_name['IssueAccessTokenRequest'] = _ISSUEACCESSTOKENREQUEST
DESCRIPTOR.message_types_by_name['AccessTokenResponse'] = _ACCESSTOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetExtensionsResponse'] = _GETEXTENSIONSRESPONSE
DESCRIPTOR.message_types_by_name['ExtensionPoint'] = _EXTENSIONPOINT
DESCRIPTOR.message_types_by_name['MessageConditions'] = _MESSAGECONDITIONS
DESCRIPTOR.message_types_by_name['GroupConditions'] = _GROUPCONDITIONS
DESCRIPTOR.enum_types_by_name['AppType'] = _APPTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MiniApp = _reflection.GeneratedProtocolMessageType('MiniApp', (_message.Message,), {

  'LocalesEntry' : _reflection.GeneratedProtocolMessageType('LocalesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MINIAPP_LOCALESENTRY,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.MiniApp.LocalesEntry)
    })
  ,
  'DESCRIPTOR' : _MINIAPP,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MiniApp)
  })
_sym_db.RegisterMessage(MiniApp)
_sym_db.RegisterMessage(MiniApp.LocalesEntry)

UpdateMiniApp = _reflection.GeneratedProtocolMessageType('UpdateMiniApp', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMINIAPP,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateMiniApp)
  })
_sym_db.RegisterMessage(UpdateMiniApp)

GetAppsRequest = _reflection.GeneratedProtocolMessageType('GetAppsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPSREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetAppsRequest)
  })
_sym_db.RegisterMessage(GetAppsRequest)

GetAppsResponse = _reflection.GeneratedProtocolMessageType('GetAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPPSRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetAppsResponse)
  })
_sym_db.RegisterMessage(GetAppsResponse)

FindAppRequest = _reflection.GeneratedProtocolMessageType('FindAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDAPPREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FindAppRequest)
  })
_sym_db.RegisterMessage(FindAppRequest)

FindAppResponse = _reflection.GeneratedProtocolMessageType('FindAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDAPPRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.FindAppResponse)
  })
_sym_db.RegisterMessage(FindAppResponse)

IssueAccessTokenRequest = _reflection.GeneratedProtocolMessageType('IssueAccessTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISSUEACCESSTOKENREQUEST,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.IssueAccessTokenRequest)
  })
_sym_db.RegisterMessage(IssueAccessTokenRequest)

AccessTokenResponse = _reflection.GeneratedProtocolMessageType('AccessTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSTOKENRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.AccessTokenResponse)
  })
_sym_db.RegisterMessage(AccessTokenResponse)

GetExtensionsResponse = _reflection.GeneratedProtocolMessageType('GetExtensionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTENSIONSRESPONSE,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetExtensionsResponse)
  })
_sym_db.RegisterMessage(GetExtensionsResponse)

ExtensionPoint = _reflection.GeneratedProtocolMessageType('ExtensionPoint', (_message.Message,), {
  'DESCRIPTOR' : _EXTENSIONPOINT,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ExtensionPoint)
  })
_sym_db.RegisterMessage(ExtensionPoint)

MessageConditions = _reflection.GeneratedProtocolMessageType('MessageConditions', (_message.Message,), {

  'MessageCondition' : _reflection.GeneratedProtocolMessageType('MessageCondition', (_message.Message,), {

    'DocumentCondition' : _reflection.GeneratedProtocolMessageType('DocumentCondition', (_message.Message,), {
      'DESCRIPTOR' : _MESSAGECONDITIONS_MESSAGECONDITION_DOCUMENTCONDITION,
      '__module__' : 'miniappsregistry_pb2'
      # @@protoc_insertion_point(class_scope:dialog.MessageConditions.MessageCondition.DocumentCondition)
      })
    ,
    'DESCRIPTOR' : _MESSAGECONDITIONS_MESSAGECONDITION,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.MessageConditions.MessageCondition)
    })
  ,
  'DESCRIPTOR' : _MESSAGECONDITIONS,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.MessageConditions)
  })
_sym_db.RegisterMessage(MessageConditions)
_sym_db.RegisterMessage(MessageConditions.MessageCondition)
_sym_db.RegisterMessage(MessageConditions.MessageCondition.DocumentCondition)

GroupConditions = _reflection.GeneratedProtocolMessageType('GroupConditions', (_message.Message,), {

  'GroupCondition' : _reflection.GeneratedProtocolMessageType('GroupCondition', (_message.Message,), {
    'DESCRIPTOR' : _GROUPCONDITIONS_GROUPCONDITION,
    '__module__' : 'miniappsregistry_pb2'
    # @@protoc_insertion_point(class_scope:dialog.GroupConditions.GroupCondition)
    })
  ,
  'DESCRIPTOR' : _GROUPCONDITIONS,
  '__module__' : 'miniappsregistry_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GroupConditions)
  })
_sym_db.RegisterMessage(GroupConditions)
_sym_db.RegisterMessage(GroupConditions.GroupCondition)


_MINIAPP_LOCALESENTRY._options = None

_CLIENTSMINIAPPSREGISTRY = _descriptor.ServiceDescriptor(
  name='ClientsMiniAppsRegistry',
  full_name='dialog.ClientsMiniAppsRegistry',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1872,
  serialized_end=2171,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindApp',
    full_name='dialog.ClientsMiniAppsRegistry.FindApp',
    index=0,
    containing_service=None,
    input_type=_FINDAPPREQUEST,
    output_type=_FINDAPPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApps',
    full_name='dialog.ClientsMiniAppsRegistry.GetApps',
    index=1,
    containing_service=None,
    input_type=_GETAPPSREQUEST,
    output_type=_GETAPPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtensions',
    full_name='dialog.ClientsMiniAppsRegistry.GetExtensions',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETEXTENSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IssueAccessToken',
    full_name='dialog.ClientsMiniAppsRegistry.IssueAccessToken',
    index=3,
    containing_service=None,
    input_type=_ISSUEACCESSTOKENREQUEST,
    output_type=_ACCESSTOKENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLIENTSMINIAPPSREGISTRY)

DESCRIPTOR.services_by_name['ClientsMiniAppsRegistry'] = _CLIENTSMINIAPPSREGISTRY

# @@protoc_insertion_point(module_scope)
